@@ -1,4 +1,4 @@
-#       $Id: Rule.pm 1652 2003-10-04 11:19:39Z richardc $
+#       $Id: Rule.pm 1562 2003-09-08 17:40:48Z richardc $
 
 package File::Find::Rule;
 use strict;
@@ -10,7 +10,7 @@ use Carp qw/croak/;
 use File::Find (); # we're only wrapping for now
 use Cwd;           # 5.00503s File::Find goes screwy with max_depth == 0
 
-$VERSION = '0.24_01';
+$VERSION = '0.20';
 
 # we'd just inherit from Exporter, but I want the colon
 sub import {
@@ -104,14 +104,12 @@ object if called as class methods.
 sub new {
     my $referent = shift;
     my $class = ref $referent || $referent;
-    bless {
-        rules    => [],  # [0]
-        subs     => [],  # [1]
-        iterator => [],
-        extras   => {},
-        maxdepth => undef,
-        mindepth => undef,
-    }, $class;
+    bless { rules    => [],  # [0]
+            subs     => [],  # [1]
+            iterator => [],
+            maxdepth => undef,
+            mindepth => undef,
+          }, $class;
 }
 
 sub _force_object {
@@ -456,21 +454,12 @@ used.
 Do not apply any tests at levels less than C<$level> (a non-negative
 integer).
 
-=item C<extras( \%extras )>
-
-Specifies extra values to pass through to C<File::File::find> as part
-of the options hash.
-
-For example this allows you to specify following of symlinks like so:
-
- my $rule = File::Find::Rule->extras({ follow => 1 });
-
 May be invoked many times per rule, but only the most recent value is
 used.
 
 =cut
 
-for my $setter (qw( maxdepth mindepth extras )) {
+for my $setter (qw( maxdepth mindepth )) {
     my $sub = sub {
         my $self = _force_object shift;
         $self->{$setter} = shift;
@@ -537,6 +526,7 @@ directories.
 sub in {
     my $self = _force_object shift;
 
+    my $cwd = getcwd;
     my @found;
     my $fragment = $self->_compile( $self->{subs} );
     my @subs = @{ $self->{subs} };
@@ -544,7 +534,6 @@ sub in {
     warn "relative mode handed multiple paths - that's a bit silly\n"
       if $self->{relative} && @_ > 1;
 
-    my $topdir;
     my $code = 'sub {
         (my $path = $File::Find::name)  =~ s#^\./##;
         my @args = ($_, $File::Find::dir, $path);
@@ -554,10 +543,10 @@ sub in {
 
         # figure out the relative path and depth
         my $relpath = $File::Find::name;
-        $relpath =~ s{^\Q$topdir\E/?}{};
+        $relpath =~ s{^\Q$File::Find::topdir\E/?}{};
         my $depth = scalar File::Spec->splitdir($relpath);
         #print "name: \'$File::Find::name\' ";
-        #print "relpath: \'$relpath\' depth: $depth relative: $relative\n";
+        #print "relpath: \'$relpath\' depth: $depth\n";
 
         defined $maxdepth && $depth >= $maxdepth
            and $File::Find::prune = 1;
@@ -570,8 +559,8 @@ sub in {
         my $discarded;
         return unless ' . $fragment . ';
         return if $discarded;
-        if ($relative) {
-            push @found, $relpath if $relpath ne "";
+        if ($relative && $relpath ne "") {
+            push @found, $relpath;
         }
         else {
             push @found, $path;
@@ -583,12 +572,7 @@ sub in {
     #print "Compiled sub: '$code'\n";
 
     my $sub = eval "$code" or die "compile error '$code' $@";
-    my $cwd = getcwd;
-    for my $path (@_) {
-        # $topdir is used for relative and maxdepth
-        $topdir = $path;
-        File::Find::find( { %{ $self->{extras} }, wanted => $sub }, $path );
-    }
+    File::Find::find( $sub, @_ );
     chdir $cwd;
 
     return @found;
